@@ -116,7 +116,7 @@ def main(global_config, **settings):
 
 def addroutes(config):
     config.add_route('healthcheck', '/healthcheck')
-    config.add_route('create_new_data_set', '/{app_url_name}/create_new_data_set/{data_set_template}/{data_set_name}', factory='tropofy.AppFactory')
+    config.add_route('create_new_data_set', '/{app_url_name}/create_new_data_set', factory='tropofy.AppFactory')
     config.add_route('start_app_with_data_set', '/{app_url_name}/start_app_with_data_set/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
     config.add_route('set_data_set_current_step', '/{app_url_name}/set_data_set_current_step/{current_step_index:\d+}/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
     config.add_route('refresh_widget_from_db', '/{app_url_name}/refresh_widget_from_db/{widget_id:\d+}/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
