@@ -33,6 +33,8 @@ class SimpleGrid(GridWidget):
     which implements function to use an instance of this widget
 
     :param source_class: A user defined SQLAlchemy Python class
+    :param editable: (Optional - default True). Enables grid to be edited.
+    :type editable: bool
 
     .. note::
         The source_class provided to a SimpleGrid must have the following properties:
@@ -44,8 +46,9 @@ class SimpleGrid(GridWidget):
     .. literalinclude:: ../../../tropofy/widgets/examples/widget_examples.py
         :pyobject: ConformingClass
     """
-    def __init__(self, source_class):
+    def __init__(self, source_class, editable=True):
         self.source_class = source_class
+        self.editable = editable
 
     def delete_row(self, obj_id):
         DbManager.delete_object_from_db(source_class=self.source_class, obj_id=obj_id)
@@ -118,4 +121,4 @@ class SimpleGrid(GridWidget):
         return 'SimpleGrid'
 
     def grid_is_editable(self):
-        return True
+        return self.editable
