@@ -25,7 +25,7 @@ from sqlalchemy.schema import Column, ForeignKeyConstraint, UniqueConstraint
 from tropofy.app import AppWithDataSets, Step, StepGroup
 from tropofy.widgets import ExecuteFunction, SimpleGrid, Chart
 from tropofy.database.tropofy_orm import DataSetMixin
-from tropofy.database import read_write_xl
+from tropofy.file_io import read_write_xl
 
 
 class ShiftRequirements(DataSetMixin):
@@ -292,7 +292,7 @@ class GurobiRosteringApp(AppWithDataSets):
 
 
 def load_gurobi_data(data_set):
-    read_write_xl.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('gurobi_rostering_data.xlsx'))
+    read_write_xl.ExcelReader.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('gurobi_rostering_data.xlsx'))
 
 
 def formulate_and_solve_staff_rostering_problem(data_set):
